@@ -22,6 +22,7 @@ class TalosClientConfig:
     _maxTotalConnectionsPerRoute = int
     _isRetry = bool
     _isAutoLocation = bool
+    _isOpenDnsResolver = bool
     _scheduleInfoMaxRetry = int
     _updateScheduleInfoInterval = int
     _falconUrl = str
@@ -107,6 +108,9 @@ class TalosClientConfig:
         self._isAutoLocation = pro.get(
             TalosClientConfigKeys.GALAXY_TALOS_CLIENT_IS_AUTO_LOCATION,
             TalosClientConfigKeys.GALAXY_TALOS_CLIENT_IS_AUTO_LOCATION_DEFAULT)
+        self._isOpenDnsResolver = pro.get(
+            TalosClientConfigKeys.GALAXY_TALOS_CLIENT_IS_OPEN_DNS_RESOLVER,
+            TalosClientConfigKeys.GALAXY_TALOS_CLIENT_IS_OPEN_DNS_RESOLVER_DEFAULT)
         self._scheduleInfoMaxRetry = pro.get(
             TalosClientConfigKeys.GALAXY_TALOS_CLIENT_SCHEDULE_INFO_MAX_RETRY,
             TalosClientConfigKeys.GALAXY_TALOS_CLIENT_SCHEDULE_INFO_MAX_RETRY_DEFAULT)
@@ -273,6 +277,9 @@ class TalosClientConfig:
     def get_is_auto_location(self):
         return self._isAutoLocation
 
+    def get_is_open_dns_resolver(self):
+        return self._isOpenDnsResolver
+
     def get_schedule_info_max_retry(self):
         return self._scheduleInfoMaxRetry
 
