@@ -45,6 +45,10 @@ class TalosClientConfigKeys:
     GALAXY_TALOS_CLIENT_IS_AUTO_LOCATION = "galaxy.talos.client.is.auto.location"
     GALAXY_TALOS_CLIENT_IS_AUTO_LOCATION_DEFAULT = True
 
+    # The client whether open dns resolver
+    GALAXY_TALOS_CLIENT_IS_OPEN_DNS_RESOLVER = "galaxy.talos.client.is.open.dns.resolver"
+    GALAXY_TALOS_CLIENT_IS_OPEN_DNS_RESOLVER_DEFAULT = True
+
     # The client get schedule info max retry
     GALAXY_TALOS_CLIENT_SCHEDULE_INFO_MAX_RETRY = "galaxy.talos.client.schedule.info.max.retry"
     GALAXY_TALOS_CLIENT_SCHEDULE_INFO_MAX_RETRY_DEFAULT = 1
