@@ -359,7 +359,8 @@ class TalosClientFactory:
         # setting 'supportAccountKey' to true for using Galaxy-V3 auth
         talosHttpClient = TalosHttpClient(self._talosClientConfig.get_service_endpoint()
                                           + Constants.TALOS_TOPIC_SERVICE_PATH,
-                                          self._credential, self._clockOffset, True)
+                                          self._credential, self._clockOffset, True,
+                                          self._talosClientConfig.get_is_open_dns_resolver())
         talosHttpClient.set_custom_headers(headers)
         talosHttpClient.set_timeout(self._talosClientConfig.get_client_conn_timeout())
         return TopicClient(talosHttpClient)
@@ -373,7 +374,8 @@ class TalosClientFactory:
         # setting 'supportAccountKey' to true for using Galaxy-V3 auth
         talosHttpClient = TalosHttpClient(self._talosClientConfig.get_service_endpoint()
                                           + Constants.TALOS_CONSUMER_SERVICE_PATH,
-                                          self._credential, self._clockOffset, True)
+                                          self._credential, self._clockOffset, True,
+                                          self._talosClientConfig.get_is_open_dns_resolver())
         talosHttpClient.set_custom_headers(headers)
         talosHttpClient.set_timeout(self._talosClientConfig.get_client_conn_timeout())
         return ConsumerClient(talosHttpClient)
@@ -392,11 +394,13 @@ class TalosClientFactory:
             talosHttpClient = TalosHttpClient(
                 self._talosClientConfig.get_service_endpoint()
                 + Constants.TALOS_MESSAGE_SERVICE_PATH,
-                self._credential, self._clockOffset, True)
+                self._credential, self._clockOffset, True,
+                self._talosClientConfig.get_is_open_dns_resolver())
         else:
             talosHttpClient = TalosHttpClient(
                 endpoint + Constants.TALOS_MESSAGE_SERVICE_PATH,
-                self._credential, self._clockOffset, True)
+                self._credential, self._clockOffset, True,
+                self._talosClientConfig.get_is_open_dns_resolver())
         talosHttpClient.set_custom_headers(headers)
         talosHttpClient.set_timeout(self._talosClientConfig.get_client_conn_timeout())
         return MessageClient(talosHttpClient)
