@@ -28,6 +28,7 @@ import logging
 import dns.resolver
 import random
 import traceback
+import IPy
 
 
 class TalosHttpClientTransportFactory:
@@ -66,6 +67,7 @@ class TalosHttpClient(TTransportBase):
     _clockOffset = 0
     _queryString = None
     _supportAccountKey = False
+    _supportDnsResolver = False
     credential = Credential
 
     __http = None
@@ -97,8 +99,9 @@ class TalosHttpClient(TTransportBase):
     #     self.__http = httpClient
     #     self.__init__(uri_or_host, credential, clockOffset, True)
 
-    def __init__(self, uri_or_host, credential=None, clockOffset=None, supportAccountKey=None,
-                port=None, path=None, cafile=None, cert_file=None, key_file=None, ssl_context=None):
+    def __init__(self, uri_or_host, credential=None, clockOffset=None,
+                 supportAccountKey=None, supportDnsResolver=None, port=None, path=None,
+                 cafile=None, cert_file=None, key_file=None, ssl_context=None):
         """THttpClient supports two different types of construction:
 
         THttpClient(host, port, path) - deprecated
@@ -151,6 +154,7 @@ class TalosHttpClient(TTransportBase):
             self.realhost = self.realport = self.proxy_auth = None
         self._clockOffset = clockOffset
         self._supportAccountKey = supportAccountKey
+        self._supportDnsResolver = supportDnsResolver
         self.credential = credential
         self.__wbuf = BytesIO()
         self.__http_response = None
@@ -449,8 +453,20 @@ class TalosHttpClient(TTransportBase):
     def set_sid(self, sid=None):
         self._sid = sid
 
+
+    def is_ip_address(self, host=None):
+        try:
+            IPy.IP(host)
+            return True
+        except Exception as e:
+            return False
+
+
     # for dns cache
     def get_addr_by_host(self, host=None):
+        if not self._supportDnsResolver or self.is_ip_address(host):
+            return host
+
         ipList = []
         try:
             A = dns.resolver.query(host)
