@@ -107,21 +107,26 @@ class SimpleProducer(object):
         try:
             putMessageResponse = self.scheduleInfoCache.get_or_create_message_client(
                 topicAndPartition=self.topicAndPartition).put_message(putMessageRequest)
-        except TTransportException as tTransportException:
-            if not self.scheduleInfoCache and self.scheduleInfoCache.get_is_auto_location():
-                self.logger.warn(
-                    "can't connect to the host directly, refresh scheduleInfo and retry using url. "
-                    + "The exception message is :" + tTransportException.message +
-                    ". Ignore this if not frequently.")
-                self.scheduleInfoCache.update_schedule_info_cache()
-                putMessageResponse = self.messageClient.put_message(putMessageRequest)
+        except Exception as e:
+            if isinstance(e, TTransportException):
+                if not self.scheduleInfoCache and self.scheduleInfoCache.get_is_auto_location():
+                    self.logger.warn(
+                        "can't connect to the host directly, refresh scheduleInfo and retry using url. "
+                        + "The exception message is :" + e.message +
+                        ". Ignore this if not frequently.")
+                    self.scheduleInfoCache.update_schedule_info_cache()
+                    putMessageResponse = self.messageClient.put_message(putMessageRequest)
+                else:
+                    self.logger.error(
+                        "put message request failed." + str(traceback.format_exc()))
+                    raise e
             else:
                 self.logger.error(
                     "put message request failed." + str(traceback.format_exc()))
-                raise tTransportException
+                raise e
 
         # update scheduleInfocache when request have been transfered and talos auto location was set up
-        if putMessageResponse.isTransfer is not None and putMessageResponse.isTransfer and self.scheduleInfoCache is not None \
+        if putMessageResponse.isTransfer and putMessageResponse.isTransfer and self.scheduleInfoCache \
                 and self.scheduleInfoCache.get_is_auto_location():
             self.logger.info(
                 "request has been transfered when talos auto location set up, refresh scheduleInfo")
